# OwnTools
2021-12-27 Created
2024-05-06 Upload to PyPi
2026-4-6 Add Translation_AI

##
0. pip install wheel twine -i https://pypi.org/simple
1. change version
2. python setup.py sdist bdist_wheel
2. python setup.py develop 
4. twine upload dist/*
****
### 2024-5-19

    1.trans_to_date
    2.trans_to_datetime

### 2026-4-6

   1. Add Translation_AI
   2. Delete unsafe key and secret key in Translation_AI and Translation
